@@ -15,11 +15,11 @@ Digest::MD6 - Perl interface to the MD6 Algorithm
 
 =head1 VERSION
 
-This document describes Digest::MD6 version 0.06
+This document describes Digest::MD6 version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our $HASH_LENGTH = 256;
 
@@ -34,15 +34,15 @@ BEGIN {
     push @EXPORT_OK, "md6_${l}", "md6_${l}_hex", "md6_${l}_base64";
     *{"md6_${l}"} = sub {
       local $Digest::MD6::HASH_LENGTH = $l;
-      md6(@_);
+      md6( @_ );
     };
     *{"md6_${l}_hex"} = sub {
       local $Digest::MD6::HASH_LENGTH = $l;
-      md6_hex(@_);
+      md6_hex( @_ );
     };
     *{"md6_${l}_base64"} = sub {
       local $Digest::MD6::HASH_LENGTH = $l;
-      md6_base64(@_);
+      md6_base64( @_ );
     };
   }
 }
@@ -78,9 +78,8 @@ __END__
 
 The C<Digest::MD6> module allows you to use the MD6 Message Digest
 algorithm from within Perl programs. The algorithm takes as input a
-## Please see file perltidy.ERR
-message of arbitrary length and produces as output a " fingerprint " or
-" message digest " of the input.
+message of arbitrary length and produces as output a "fingerprint" or
+"message digest" of the input.
 
 =head1 INTERFACE
 
@@ -136,7 +135,16 @@ available:
   md6_384 md6_384_base64 md6_384_hex
   md6_512 md6_512_base64 md6_512_hex
 
-These set the hash length before encoding.
+These set the hash length before encoding, so instead of writing:
+
+  {
+    local $Digest::MD6::HASH_LENGTH = 512;
+    my $hash = md6_hex( $data );
+  }
+
+you can just:
+
+  my $hash = md6_512_hex( $data );
 
 =head1 METHODS
 
